@@ -1,7 +1,10 @@
 import os
 import flask
+import sys
 
 def serve_local_model():
+  print('> Adding this directory to python path')
+  sys.path.insert(1, os.getcwd())
   # check that files exist
   print('> Loading predictor.py...')
   try:
